==> haskell-conduit-extra-1.3.8-67.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-extra
version:              1.3.8
visibility:           public
id:                   conduit-extra-1.3.8-2AxhzRoObWI6EssRdl8CoW
key:                  conduit-extra-1.3.8-2AxhzRoObWI6EssRdl8CoW
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  9ab691743a6873d09d6cb231df4afe38
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.8-2AxhzRoObWI6EssRdl8CoW
depends:
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    directory-1.3.8.5 filepath-1.4.300.1
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ process-1.6.19.0
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx stm-2.5.1.0
    streaming-commons-0.2.3.0-E1A8MXIidsEIETQNDtfU1f text-2.0.2
    transformers-0.6.1.0 typed-process-0.2.13.0-EqZPeHIjk7UIrsbWZqASrc
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.3.8-68-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-extra
version:              1.3.8
visibility:           public
id:                   conduit-extra-1.3.8-E4AHXAfmerjKj7JfHrF3lm
key:                  conduit-extra-1.3.8-E4AHXAfmerjKj7JfHrF3lm
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://github.com/snoyberg/conduit
synopsis:             Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.

category:             Data, Conduit
abi:                  b818ba9a5a7879604da1d3d1949aeb3f
exposed:              True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib

import-dirs:          /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/conduit-extra-1.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-extra
hs-libraries:         HSconduit-extra-1.3.8-E4AHXAfmerjKj7JfHrF3lm
depends:
    async-2.2.5-1Z88VuXAsSjFYCStMD3XFv
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    directory-1.3.8.5 filepath-1.4.300.1
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ process-1.6.19.0
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx stm-2.5.1.0
    streaming-commons-0.2.3.1-JQd7Uft3nuo1D7ll7sM2yO text-2.0.2
    transformers-0.6.1.0 typed-process-0.2.13.0-EqZPeHIjk7UIrsbWZqASrc
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock

haddock-html:         /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
